/* $Id: treohelper.h,v 1.79 2004/04/23 05:07:24 chrisf Exp $ */

/*
Treoff - Utility to manage power off of Treo
Copyright (C) 2003 Chris Faherty

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef __TREOHELPER_H__
#define __TREOHELPER_H__

#include <Handspring/HsExt.h>

/*
 * This flag (0 or 1) controls the ShowDebugMsg().. basically just showing
 * some extra messages on the screen.  Not extremely useful.
 */
#define DEBUGMSG 0

#define MainAppID 'THEL'
#define MainDBType 'DATA'

#define AppErrStrLen 32
#define ErrToString(err) SysErrString(err,AppErrStr,AppErrStrLen)

/* some of these features are used to multiplex alarms */
#define FTR_COVERAGELOSS 0
#define FTR_RESET 1
#define FTR_PHONETURNON 2
#define FTR_PHONETURNOFF 3
#define FTR_DROPNETGREENTIME 4
#define FTR_DROPNETGREYTIME 5
#define FTR_DROPNETCOVERAGE 6
#define FTR_PHONEONEVERY 7
#define FTR_PHONEONTRIES 8
#define FTR_AUTOOKCONNECT 9
#define FTR_AUTOLOGIN 10
#define FTR_STOPTONE 11
#define FTR_DELAYLAUNCH 12
#define FTR_HANDSFREEDIAL 13
#define FTR_LIDOPENED 14
/* holds procalarm callback since it can change after hotsync */
#define FTR_PROCALARM_FUNC 15

/* last SMS texts -- these are FtrPtrNew() */
#define FTR_SMS1 1001
#define FTR_SMS2 1002
#define FTR_SMS3 1003
#define FTR_SMS4 1004
#define FTR_SMS5 1005
#define FTR_SMS6 1006
#define FTR_SMS7 1007
#define FTR_SMS8 1008
#define FTR_SMSDEF 1009

#define WHICHPREFS_PHONEFLAGS 0
#define WHICHPREFS_DROPNET 1
#define WHICHPREFS_ALL 255

struct sprefs {
    UInt16 lidofftime; /* seconds */
    UInt16 phoneofftime; /* minutes */
    UInt16 phoneturnon; /* minutes */
    UInt16 phoneturnoff; /* minutes */
    UInt16 dropnetgreentime; /* seconds */
    UInt16 dropnetgreytime; /* seconds */
    UInt16 dropnetcoverage; /* seconds */
    UInt8 phoneonofftype; /* 0=daily(use phoneturnon), 1=weekly(use array) */
    UInt16 phoneweekonoff[14]; /* minutes */
    UInt8 phoneontries; /* max tries to turn phone on after coverage loss */
    UInt16 phoneonevery; /* minutes - interval for attempt */
    #define PHONEFLAGS_ENABLEPHONEONRESET  0x1
    #define PHONEFLAGS_STAYONLIDNETWORK    0x2
    #define PHONEFLAGS_AUTOOKCONNECT       0x4
    #define PHONEFLAGS_AUTOLOGIN           0x8
    #define PHONEFLAGS_ENABLEPOWERONTONE   0x10
    #define PHONEFLAGS_ENABLEPOWEROFFTONE  0x20
    #define PHONEFLAGS_ENABLEHANDSFREEDIAL 0x40
    UInt32 phoneflags; /* combined booleans */
    #define FUNENTRIES 2
    UInt32 funtone[FUNENTRIES]; /* [0]=power on [1]=power off */
    UInt16 funduration[FUNENTRIES];
    UInt16 funvolume[FUNENTRIES];
    #define MAX_PHONE_NUMBER 32
    char funhandsfreenumber[MAX_PHONE_NUMBER+1];
    #define SMSFLAGS_ENABLETRIG  0x1
    #define SMSFLAGS_ENABLETONE  0x2
    #define SMSFLAGS_VIBRATE     0x4
    #define SMSFLAGS_DELETE      0x8
    #define SMSFLAGS_DELAYLAUNCH 0x10
    #define SMSENTRIES 9
    UInt32 smsflags[SMSENTRIES]; /* flags */
    char smstrigtext[SMSENTRIES][33]; /* asciiz strings */
    UInt32 smslaunch[SMSENTRIES]; /* these are crID 0=don't */
    UInt32 smstone[SMSENTRIES]; /* this identifies the tone */
    UInt16 smsduration[SMSENTRIES]; /* seconds */
    UInt16 smsvolume[SMSENTRIES]; /* 0=off 1=soft 2=medium 3=loud */
};

#define SECONDSLIST 19
const UInt16 secondslist[SECONDSLIST]=
    {5, 10, 15, 20, 30, 45, 60, 90, 2*60, 3*60, 4*60, 5*60, 10*60, 15*60,
    30*60, 3600, 2*3600, 3*3600, 4*3600};
#define SECONDSLIST2 20
const UInt16 secondslist2[SECONDSLIST2]=
    {0, 5, 10, 15, 20, 30, 45, 60, 90, 2*60, 3*60, 4*60, 5*60, 10*60, 15*60,
    30*60, 3600, 2*3600, 3*3600, 4*3600};
#define MINUTESLIST 12
const UInt16 minuteslist[MINUTESLIST]=
    {0, 1, 2, 3, 4, 5, 10, 30, 60, 2*60, 3*60, 4*60};

/* this is const so that it will remain available to HsIndicator() */
/* vibrate for 3/4 second */
const HsIndicatorSequence ics[3]={
    {hsIndicatorCapVibrator, hsIndicatorDelayOneSecond*3/4},
    {hsIndicatorCapOff, hsIndicatorDelayOneSecond*3/4},
    {hsIndicatorCapLast, 0}
};

/* function prototypes */

Boolean MainFormHandleEvent(EventPtr e);
Boolean DropnetFormHandleEvent(EventPtr e);
Boolean SMSFormHandleEvent(EventPtr e);
Boolean FunFormHandleEvent(EventPtr e);
Boolean AboutFormHandleEvent(EventPtr e);
Boolean ContribFormHandleEvent(EventPtr e);
Boolean WeekFormHandleEvent(EventPtr e);
void set_closest_seconds(FormPtr frm, UInt16 listID, UInt16 poptrigID,
    UInt16 secs);
void set_closest_seconds2(FormPtr frm, UInt16 listID, UInt16 poptrigID,
    UInt16 secs);
void set_closest_minutes(FormPtr frm, UInt16 listID, UInt16 poptrigID,
    UInt16 mins);
void set_closest_time(FormPtr frm, UInt16 listID, UInt16 poptrigID, UInt16 mins);
void set_smstrig(FormPtr frm, Int16 which);
void set_fun(FormPtr frm);
void UpdateLabels(void);
void UpdateValues(void);
Int16 MatchSMStext(UInt16 plibr, struct sprefs *tprefs, char *txt);
void do_sms_launch(struct sprefs *tprefs, char *txt, UInt16 which);
void VersaMailCheck(void);
void GGMCheckMail(void);
void GGMRefreshList(void);
FieldPtr GetFocusObjectPtr(void);
Boolean FormHandleMenuEvent(UInt16 menuID);
Boolean ApplicationHandleEvent(EventPtr e);
UInt16 StartApplication(void);
void StopApplication(void);
void EventLoop(void);
Boolean is_os_32(void);
Boolean is_os_5x(void);
void register_notifyevent(UInt32 e);
void unregister_notifyevent(UInt32 e);
UInt32 WhichPhoneType(void);
Err LoadPhoneLibrary(UInt16 *plref);
void ClosePhoneLibrary(UInt16 plref);
Err UseNetMasterLibrary(UInt16 *nmlref);
void LoadPrefs(struct sprefs *prefs, UInt8 whichprefs);
Boolean LoadTempPrefs(struct sprefs **prefs, UInt8 whichprefs);
void UnloadTempPrefs(struct sprefs *prefs);
void SavePrefs(struct sprefs *prefs);
void SetTimeOfNextAlarm(UInt32 alarmTime, UInt32 ref, AlmAlarmProcPtr procP);
UInt32 GetTimeOfNextAlarm(UInt32 *refP, AlmAlarmProcPtr procP);
void sync_autologin_setting(struct sprefs *tprefs, Boolean forceoff);
void phone_events_register(UInt16 plref, struct sprefs *tprefs);
void phone_events_unregister(UInt16 plref);
void AlarmProcMulti(UInt16 almProcCmd, SysAlarmTriggeredParamType *paramP);
void DisplayAlarm(SysDisplayAlarmParamType *paramP);
void GenericAlarm(UInt32 ref, UInt32 alarmSeconds);
void AlarmTriggered(SysAlarmTriggeredParamType *paramP);
void dismiss_progress_dialog(void);
void dismiss_progress_dialog_generic(void);
void set_next_alarm_ref(void);
UInt32 midnight_seconds(UInt32 tgs);
UInt32 monday_seconds(UInt32 tgs);
void set_phoneonoff_times(struct sprefs *tprefs, UInt32 tgs);
void set_dropnet_times(struct sprefs *tprefs, UInt32 tgs);
Boolean should_phone_be_on(struct sprefs *tprefs, UInt32 tgs);
Boolean HandleSMS(UInt32 messageID);
Err TreoGetToneIDs(UInt16 refNum, void **list, UInt16 *listLength);
Err TreoGetToneName(UInt16 refNum, UInt32 tone, char *name,
    UInt16 maxLength);
Err TreoGetToneNameIdx(UInt16 refNum, UInt16 toneidx, char *name,
    UInt16 maxLength);
Err TreoPlayTone(UInt16 refNum, UInt32 tone, UInt16 volume, Boolean vibrate,
    UInt16 duration);
void ToneListDrawItem(Int16 itemNum, RectanglePtr bounds, char **unusedP);
UInt32 ToneList(UInt16 listid, UInt16 triggerid, UInt32 curtone);
Boolean is_lid_open(void);
Boolean is_display_on(void);
Boolean was_lid_opened(void);
Err dial_phone(char *txt);
UInt32 HandleLaunchCodes(UInt16 cmd, void *cmdPBP, UInt16 launchFlags);
UInt32 PilotMain(UInt16 cmd, void *cmdPBP, UInt16 launchFlags);

#endif
